==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/File/NewFile/ts/NewFile_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>CloseDialog</name>
    <message>
        <location filename="../CloseDialog.ui" line="+14"/>
        <source>Closing Drawing...</source>
        <translation>Zapiram risbo...</translation>
    </message>
</context>
<context>
    <name>Form</name>
    <message>
        <location filename="../MdiChildEmpty.ui" line="+20"/>
        <source>Untitled</source>
        <translation>Brez naslova</translation>
    </message>
</context>
<context>
    <name>NewFile</name>
    <message>
        <location filename="../NewFile.js" line="+120"/>
        <source>Loading...</source>
        <translation>Odpiram...</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Import Error</source>
        <translation>Napaka pri uvozu</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Cannot open file</source>
        <translation>Ne morem odpret datoteke</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>No suitable Importer found. Please check file format and extension.</source>
        <translation>Pretvorba ni mogoča. Preverite datotečni format ter končnico.</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Please check your access rights, the file format and file extension.</source>
        <translation>Preverite vaše pravice dostopa, datotečni format ter končnico datoteke.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>File is empty.</source>
        <translation>Datoteka je prazna</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Opened drawing:</source>
        <translation>Odprta risba</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Format:</source>
        <translation>Format:</translation>
    </message>
    <message>
        <location line="+92"/>
        <source>Untitled %1</source>
        <translation>Brez naslova %1</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>read-only</source>
        <translation>Samo za branje</translation>
    </message>
    <message>
        <location line="+41"/>
        <source>Do you want to save the changes you made in&lt;br&gt;the document &apos;%1&apos;?</source>
        <translation>Želite shranit spremembe v&lt;br&gt;&apos;%1&apos; ?</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translation>Vse spremembe bodo izkubljene, če jih ne shranite.</translation>
    </message>
    <message>
        <location filename="../NewFileInit.js" line="+2"/>
        <source>&amp;New</source>
        <translation>&amp;Nova</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/File/NewFile/ts/NewFile_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>CloseDialog</name>
    <message>
        <location filename="../CloseDialog.ui" line="+14"/>
        <source>Closing Drawing...</source>
        <translation>Zapiram risbo...</translation>
    </message>
</context>
<context>
    <name>Form</name>
    <message>
        <location filename="../MdiChildEmpty.ui" line="+20"/>
        <source>Untitled</source>
        <translation>Brez naslova</translation>
    </message>
</context>
<context>
    <name>NewFile</name>
    <message>
        <location filename="../NewFile.js" line="+114"/>
        <source>Opening drawing:</source>
        <translation>Odpiram risbo:</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation type="vanished">Odpiram...</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Import Error</source>
        <translation>Napaka pri uvozu</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Cannot open file</source>
        <translation>Ne morem odpret datoteke</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>No suitable Importer found. Please check file format and extension.</source>
        <translation>Pretvorba ni mogoča. Preverite datotečni format ter končnico.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>File not found.</source>
        <translation>Ne najdem datoteke.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Please check your access rights, the file format and file extension.</source>
        <translation>Preverite vaše pravice dostopa, datotečni format ter končnico datoteke.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Import failed.</source>
        <translation>Uvoz spodletel.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>File is empty.</source>
        <translation>Datoteka je prazna.</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Drawing loaded successfully:</source>
        <translation>Risba naložena uspešno:</translation>
    </message>
    <message>
        <source>Opened drawing:</source>
        <translation type="vanished">Odprta risba:</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Format:</source>
        <translation>Format:</translation>
    </message>
    <message>
        <location line="+124"/>
        <source>Untitled %1</source>
        <translation>Brez naslova %1</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>read-only</source>
        <translation>Samo za branje</translation>
    </message>
    <message>
        <location line="+53"/>
        <source>Do you want to save the changes you made in&lt;br&gt;the document &apos;%1&apos;?</source>
        <translation>Želite shranit spremembe v&lt;br&gt;&apos;%1&apos; ?</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translation>Vse spremembe bodo izkubljene, če jih ne shranite.</translation>
    </message>
    <message>
        <location filename="../NewFileInit.js" line="+2"/>
        <source>&amp;New</source>
        <translation>&amp;Nova</translation>
    </message>
</context>
</TS>
